@@ -16,9 +16,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
    As a special exception, the authors of SANE give permission for
    additional uses of the libraries contained in this release of SANE.
@@ -120,7 +118,7 @@ typedef struct Avision_HWEntry {
     /* if the scan area and resolution needs to be forced for films */
   #define AV_FORCE_FILM ((uint64_t)1<<6)
 
-    /* does not suport, or very broken background (added for AV610C2) */
+    /* does not support, or very broken background (added for AV610C2) */
   #define AV_NO_BACKGROUND ((uint64_t)1<<7)
 
     /* is film scanner - no detection yet */
@@ -171,7 +169,7 @@ typedef struct Avision_HWEntry {
     /* though marked as GRAY only the scanner can do GRAY modes */
   #define AV_GRAY_MODES ((uint64_t)1<<23)
 
-    /* no seperate, single REAR scan (AV122, DM152, ...) */
+    /* no separate, single REAR scan (AV122, DM152, ...) */
   #define AV_NO_REAR ((uint64_t)1<<24)
 
     /* only scan with some known good hardware resolutions, as the
@@ -180,11 +178,11 @@ typedef struct Avision_HWEntry {
        interpolate to all the others */
   #define AV_SOFT_SCALE ((uint64_t)1<<25)
 
-    /* does keep window though it does not advertice it - the AV122/DM152
+    /* does keep window though it does not advertise it - the AV122/DM152
        mess up image data if window is resend between ADF pages */
   #define AV_DOES_KEEP_WINDOW ((uint64_t)1<<26)
 
-    /* does keep gamma though it does not advertice it */
+    /* does keep gamma though it does not advertise it */
   #define AV_DOES_KEEP_GAMMA ((uint64_t)1<<27)
 
     /* does the scanner contain a Cancel button? */
@@ -463,12 +461,12 @@ typedef struct Avision_Device
   int scsi_buffer_size; /* nice to have SCSI buffer size */
   int read_stripe_size; /* stripes to be read at-a-time */
 
-  /* film scanner atributes - maybe these should be in the scanner struct? */
+  /* film scanner attributes - maybe these should be in the scanner struct? */
   SANE_Range frame_range;
   SANE_Word current_frame;
   SANE_Word holder_type;
 
-  /* some versin corrections */
+  /* some version corrections */
   uint16_t data_dq; /* was ox0A0D - but hangs some new scanners */
 
   Avision_HWEntry* hw;
@@ -773,7 +771,7 @@ typedef struct calibration_format
   uint16_t g_dark_shading_target;
   uint16_t b_dark_shading_target;
 
-  /* not returned but usefull in some places */
+  /* not returned but useful in some places */
   uint8_t channels;
 } calibration_format;
 
@@ -853,4 +851,29 @@ extern SANE_Status ENTRY(media_check) (SANE_Handle handle);
 
 #endif
 
+typedef enum
+{
+  AVISION_DATATYPECODE_READ_IMAGE_DATA = 0x00,
+  AVISION_DATATYPECODE_GET_CALIBRATION_FORMAT = 0x60,
+  AVISION_DATATYPECODE_DETECT_ACCESSORIES = 0x64,
+  AVISION_DATATYPECODE_READ_NVRAM_DATA = 0x69,
+  AVISION_DATATYPECODE_FLASH_RAM_INFO = 0x6a,
+  AVISION_DATATYPECODE_ACCELERATION_TABLE = 0x6c,
+  AVISION_DATATYPECODE_DOWNLOAD_GAMMA_TABLE = 0x81,
+  AVISION_DATATYPECODE_3X3_COLOR_MATRIX = 0x83,
+  AVISION_DATATYPECODE_SEND_NVRAM_DATA = 0x85,
+  AVISION_DATATYPECODE_FLASH_DATA = 0x86,
+  AVISION_DATATYPECODE_FILM_HOLDER_SENSE = 0x87,
+  AVISION_DATATYPECODE_FIRMWARE_STATUS = 0x90,
+  AVISION_DATATYPECODE_ATTACH_TRUNCATE_TAIL = 0x95,
+  AVISION_DATATYPECODE_ATTACH_TRUNCATE_HEAD = 0x96,
+  AVISION_DATATYPECODE_GET_BACKGROUND_RASTER = 0x9b,
+  AVISION_DATATYPECODE_LIGHT_STATUS = 0xa0,
+  AVISION_DATATYPECODE_BUTTON_STATUS = 0xa1,
+  AVISION_DATATYPECODE_POWER_SAVING_TIMER = 0xa2,
+  AVISION_DATATYPECODE_READ_DUPLEX_INFO = 0xb1,
+  AVISION_DATATYPECODE_UNKNOWN = 0xd0,
+  AVISION_DATATYPECODE_READ_GENERAL_ABILITY_PARAM = 0xd2,
+} Avision_Datatypecode;
+
 #endif /* avision_h */
