@@ -21,9 +21,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
    As a special exception, the authors of SANE give permission for
    additional uses of the libraries contained in this release of SANE.
@@ -55,10 +53,10 @@
    . - sane_open() : open a particular scanner-device and attach_scanner(devicename,&dev)
    . . - sane_set_io_mode : set blocking-mode
    . . - sane_get_select_fd : get scanner-fd
-   . . - sane_get_option_descriptor() : get option informations
+   . . - sane_get_option_descriptor() : get option information
    . . - sane_control_option() : change option values
    . .
-   . . - sane_start() : start image aquisition
+   . . - sane_start() : start image acquisition
    . .   - sane_get_parameters() : returns actual scan-parameters
    . .   - sane_read() : read image-data (from pipe)
    . . - sane_cancel() : cancel operation, kill reader_process
@@ -82,9 +80,9 @@
  . - init_options
  - sane_set_io_mode : set blocking-mode
  - sane_get_select_fd : get scanner-fd
- - sane_get_option_descriptor() : get option informations
+ - sane_get_option_descriptor() : get option information
  - sane_control_option() : change option values
- - sane_start() : start image aquisition
+ - sane_start() : start image acquisition
    - sane_get_parameters() : returns actual scan-parameters
    - sane_read() : read image-data (from pipe)
    - sane_cancel() : cancel operation, kill reader_process
