@@ -17,11 +17,9 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-   This file implements a SANE backend for the Canon CanoScan LiDE 70 */
+   This file implements a SANE backend for the Canon CanoScan LiDE 70 and 600 */
 
 #define BUILD 0
 #define MM_IN_INCH 25.4
@@ -227,10 +225,10 @@ sane_init (SANE_Int * version_code, SANE_Auth_Callback authorize)
   DBG (2, "sane_init: version_code %s 0, authorize %s 0\n",
        version_code == 0 ? "=" : "!=", authorize == 0 ? "=" : "!=");
   DBG (1, "sane_init: SANE Canon LiDE70 backend version %d.%d.%d from %s\n",
-       V_MAJOR, V_MINOR, BUILD, PACKAGE_STRING);
+       SANE_CURRENT_MAJOR, SANE_CURRENT_MINOR, BUILD, PACKAGE_STRING);
 
   if (version_code)
-    *version_code = SANE_VERSION_CODE (V_MAJOR, V_MINOR, BUILD);
+    *version_code = SANE_VERSION_CODE (SANE_CURRENT_MAJOR, SANE_CURRENT_MINOR, BUILD);
 
   sanei_usb_init ();
 
@@ -391,6 +389,10 @@ init_options (CANON_Handle * chndl)
   od->size = sizeof (SANE_Word);
   od->cap = SANE_CAP_SOFT_DETECT | SANE_CAP_SOFT_SELECT;
   od->constraint_type = SANE_CONSTRAINT_WORD_LIST;
+  if (chndl->productcode == 0x2224)
+    {
+      resolution_list[0] = 4;
+    }
   od->constraint.word_list = resolution_list;
   chndl->val[opt_resolution].w = init_resolution;
 
