@@ -13,9 +13,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
    As a special exception, the authors of SANE give permission for
    additional uses of the libraries contained in this release of SANE.
@@ -477,9 +475,6 @@ load (struct backend *be)
 	  DBG (1, "load: malloc failed: %s\n", strerror (errno));
 	  return SANE_STATUS_NO_MEM;
 	}
-      if (orig_src)
-        free (orig_src);
-      orig_src = src;
       snprintf (src, src_len, "%s%s%s", path, DIR_SEP, LIBDIR);
     }
   else
@@ -494,6 +489,7 @@ load (struct backend *be)
     }
   DBG (3, "load: searching backend `%s' in `%s'\n", be->name, src);
 
+  orig_src = src;
   dir = strsep (&src, DIR_SEP);
 
   while (dir)
