@@ -16,9 +16,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
    As a special exception, the authors of SANE give permission for
    additional uses of the libraries contained in this release of SANE.
@@ -44,8 +42,6 @@
    This file implements a SANE backend for the Polaroid Digital
    Microscope Camera. */
 
-/* $Id$ */
-
 #include "../include/sane/config.h"
 
 #include <limits.h>
@@ -113,7 +109,7 @@ static SANE_Word ValidASAs[] = { 3, 25, 50, 100 };
 // fd -- file descriptor
 // typecode -- data type code
 // qualifier -- data type qualifier
-// maxlen -- tranfer length
+// maxlen -- transfer length
 // buf -- buffer to store data in
 // len -- set to actual length of data
 //%RETURNS:
@@ -153,7 +149,7 @@ DMCRead(int fd, unsigned int typecode, unsigned int qualifier,
 // fd -- file descriptor
 // typecode -- data type code
 // qualifier -- data type qualifier
-// maxlen -- tranfer length
+// maxlen -- transfer length
 // buf -- buffer to store data in
 //%RETURNS:
 // A SANE status code
@@ -820,7 +816,7 @@ sane_init(SANE_Int *version_code, SANE_Auth_Callback authorize)
 
     DBG_INIT();
     if (version_code) {
-	*version_code = SANE_VERSION_CODE (SANE_CURRENT_MAJOR, V_MINOR, 0);
+	*version_code = SANE_VERSION_CODE (SANE_CURRENT_MAJOR, SANE_CURRENT_MINOR, 0);
     }
 
     fp = sanei_config_open(DMC_CONFIG_FILE);
