@@ -277,6 +277,8 @@ wake_up_device:
         curl_easy_setopt(curl_handle, CURLOPT_POSTFIELDSIZE, upload->size);
         curl_easy_setopt(curl_handle, CURLOPT_HEADERFUNCTION, download_callback);
         curl_easy_setopt(curl_handle, CURLOPT_HEADERDATA, (void *)download);
+        curl_easy_setopt(curl_handle, CURLOPT_FOLLOWLOCATION, 1L);
+        curl_easy_setopt(curl_handle, CURLOPT_MAXREDIRS, 3L);
         CURLcode res = curl_easy_perform(curl_handle);
         if (res != CURLE_OK) {
             DBG( 1, "Create NewJob : the scanner responded incorrectly: %s\n", curl_easy_strerror(res));
@@ -296,7 +298,17 @@ wake_up_device:
                           result = strdup(location);
                           DBG( 1, "Create NewJob : %s\n", result);
                           *temporary = '\n';
+                          *location = '\0';
+                          location = strrchr(tmp_location,'/');
                           wakup_count = 0;
+                          if (location) {
+                             location++;
+                             scanner->scanJob = strdup(location);
+                             DBG( 1, "Full location header [%s]\n", scanner->scanJob);
+                          }
+                          else
+                             scanner->scanJob = strdup("ScanJobs");
+                          *location = '/';
                        }
                     }
                     if (result == NULL) {
