@@ -19,27 +19,6 @@
 
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
-   As a special exception, the authors of SANE give permission for
-   additional uses of the libraries contained in this release of SANE.
-
-   The exception is that, if you link a SANE library with other files
-   to produce an executable, this does not by itself cause the
-   resulting executable to be covered by the GNU General Public
-   License.  Your use of that executable is in no way restricted on
-   account of linking the SANE library code into it.
-
-   This exception does not, however, invalidate any other reasons why
-   the executable file might be covered by the GNU General Public
-   License.
-
-   If you submit changes to SANE to the maintainers to be included in
-   a subsequent release, you agree by submitting the changes that
-   those changes may be distributed with this exception intact.
-
-   If you write modifications of your own for SANE, it is your choice
-   whether to permit this exception to apply to your modifications.
-   If you do not wish that, delete this exception notice.
 */
 
 #ifndef GENESYS_H
@@ -124,6 +103,7 @@ enum Genesys_Option
   OPT_OCR_SW,
   OPT_POWER_SW,
   OPT_EXTRA_SW,
+  OPT_TRANSP_SW,
   OPT_NEED_CALIBRATION_SW,
   OPT_BUTTON_GROUP,
   OPT_CALIBRATE,
@@ -144,6 +124,7 @@ enum GenesysButtonName : unsigned {
     BUTTON_OCR_SW,
     BUTTON_POWER_SW,
     BUTTON_EXTRA_SW,
+    BUTTON_TRANSP_SW,
     NUM_BUTTONS
 };
 
