@@ -13,9 +13,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
    As a special exception, the authors of SANE give permission for
    additional uses of the libraries contained in this release of SANE.
@@ -40,7 +38,6 @@
 */
 
 /*
-	$Id$
         This file implements a SANE backend for Ricoh flatbed scanners.
 */
 
@@ -167,7 +164,7 @@ attach (const char *devnam, Ricoh_Device ** devp)
   status = object_position (fd);
   if (status != SANE_STATUS_GOOD)
     {
-      DBG (1, "attach: OBJECT POSTITION failed\n");
+      DBG (1, "attach: OBJECT POSITION failed\n");
       sanei_scsi_close (fd);
       return (SANE_STATUS_INVAL);
     }
@@ -243,7 +240,7 @@ attach (const char *devnam, Ricoh_Device ** devp)
   dev->info.yres_default = _2btol(wbuf.y_res);
   dev->info.image_mode_default = wbuf.image_comp;
 
-  /* if you throw the MRIF bit the brighness control reverses too */
+  /* if you throw the MRIF bit the brightness control reverses too */
   /* so I reverse the reversal in software for symmetry's sake */
   /* I should make this into an option */
 
@@ -467,7 +464,7 @@ do_cancel (Ricoh_Scanner * s)
   status = object_position (s->fd);
   if (status != SANE_STATUS_GOOD)
     {
-      DBG (1, "cancel: OBJECT POSTITION failed\n");
+      DBG (1, "cancel: OBJECT POSITION failed\n");
     }
 
   s->scanning = SANE_FALSE;
@@ -498,7 +495,7 @@ sane_init (SANE_Int * version_code, SANE_Auth_Callback authorize)
 #endif
 
   if (version_code)
-    *version_code = SANE_VERSION_CODE (SANE_CURRENT_MAJOR, V_MINOR, 0);
+    *version_code = SANE_VERSION_CODE (SANE_CURRENT_MAJOR, SANE_CURRENT_MINOR, 0);
 
   fp = sanei_config_open(RICOH_CONFIG_FILE);
   if (fp)
@@ -849,7 +846,7 @@ sane_start (SANE_Handle handle)
   _lto4b(s->length, wbuf.length);
 
   wbuf.image_comp = s->image_composition;
-  /* if you throw the MRIF bit the brighness control reverses too */
+  /* if you throw the MRIF bit the brightness control reverses too */
   /* so I reverse the reversal in software for symmetry's sake */
   if (wbuf.image_comp == RICOH_GRAYSCALE || wbuf.image_comp == RICOH_DITHERED_MONOCHROME)
     {
