@@ -15,9 +15,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
    As a special exception, the authors of SANE give permission for
    additional uses of the libraries contained in this release of SANE.
@@ -440,10 +438,10 @@ sane_init (SANE_Int * version_code, SANE_Auth_Callback authorize)
   DBG_INIT ();
 
   DBG (2, "SANE v4l backend version %d.%d build %d from %s\n", SANE_CURRENT_MAJOR,
-       V_MINOR, BUILD, PACKAGE_STRING);
+       SANE_CURRENT_MINOR, BUILD, PACKAGE_STRING);
 
   if (version_code)
-    *version_code = SANE_VERSION_CODE (SANE_CURRENT_MAJOR, V_MINOR, BUILD);
+    *version_code = SANE_VERSION_CODE (SANE_CURRENT_MAJOR, SANE_CURRENT_MINOR, BUILD);
 
   fp = sanei_config_open (V4L_CONFIG_FILE);
   if (!fp)
@@ -731,7 +729,7 @@ sane_control_option (SANE_Handle handle, SANE_Int option,
        action == SANE_ACTION_GET_VALUE ? "get" :
        action == SANE_ACTION_SET_VALUE ? "set" :
        action == SANE_ACTION_SET_AUTO ? "auto set" :
-       "(unknow action with)", option,
+       "(unknown action with)", option,
        s->opt[option].name ? s->opt[option].name : s->opt[option].title);
 
   cap = s->opt[option].cap;
