@@ -15,9 +15,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As a special exception, the authors of SANE give permission for
  * additional uses of the libraries contained in this release of SANE.
@@ -135,11 +133,9 @@ inb( u_long port )
 #include "../include/sane/sanei_debug.h"
 #include "../include/sane/sanei_pp.h"
 
-#if defined(STDC_HEADERS)
-# include <errno.h>
-# include <stdio.h>
-# include <stdlib.h>
-#endif
+#include <errno.h>
+#include <stdio.h>
+#include <stdlib.h>
 #if defined(HAVE_STRING_H)
 # include <string.h>
 #elif defined(HAVE_STRINGS_H)
@@ -1333,7 +1329,7 @@ sanei_pp_open( const char *dev, int *fd )
 	DBG( 6, "sanei_pp_open: basically, this backend does only compile\n" );
 	DBG( 6, "sanei_pp_open: on x86 architectures. Furthermore it\n" );
 	DBG( 6, "sanei_pp_open: needs ioperm() and inb()/outb() calls.\n" );
-	DBG( 6, "sanei_pp_open: alternativly it makes use of libieee1284\n" );
+	DBG( 6, "sanei_pp_open: alternatively it makes use of libieee1284\n" );
 	DBG( 6, "sanei_pp_open: (which isn't present either)\n");
 	return SANE_STATUS_INVAL;
 }
